@@ -465,10 +465,15 @@ int nv_drm_prime_fence_context_create_ioctl(struct drm_device *dev,
 {
     struct nv_drm_device *nv_dev = to_nv_device(dev);
     struct drm_nvidia_prime_fence_context_create_params *p = data;
-    struct nv_drm_prime_fence_context *nv_prime_fence_context =
-        __nv_drm_prime_fence_context_new(nv_dev, p);
+    struct nv_drm_prime_fence_context *nv_prime_fence_context;
     int err;
 
+    if (nv_dev->pDevice == NULL) {
+        return -EOPNOTSUPP;
+    }
+
+    nv_prime_fence_context = __nv_drm_prime_fence_context_new(nv_dev, p);
+
     if (!nv_prime_fence_context) {
         goto done;
     }
@@ -523,6 +528,11 @@ int nv_drm_gem_prime_fence_attach_ioctl(struct drm_device *dev,
     struct nv_drm_fence_context *nv_fence_context;
     nv_dma_fence_t *fence;
 
+    if (nv_dev->pDevice == NULL) {
+        ret = -EOPNOTSUPP;
+        goto done;
+    }
+
     if (p->__pad != 0) {
         NV_DRM_DEV_LOG_ERR(nv_dev, "Padding fields must be zeroed");
         goto done;
@@ -1312,6 +1322,10 @@ int nv_drm_semsurf_fence_ctx_create_ioctl(struct drm_device *dev,
     struct nv_drm_semsurf_fence_ctx *ctx;
     int err;
 
+    if (nv_dev->pDevice == NULL) {
+        return -EOPNOTSUPP;
+    }
+
     if (p->__pad != 0) {
         NV_DRM_DEV_LOG_ERR(nv_dev, "Padding fields must be zeroed");
         return -EINVAL;
@@ -1473,6 +1487,11 @@ int nv_drm_semsurf_fence_create_ioctl(struct drm_device *dev,
     int ret = -EINVAL;
     int fd;
 
+    if (nv_dev->pDevice == NULL) {
+        ret = -EOPNOTSUPP;
+        goto done;
+    }
+
     if (p->__pad != 0) {
         NV_DRM_DEV_LOG_ERR(nv_dev, "Padding fields must be zeroed");
         goto done;
@@ -1635,6 +1654,10 @@ int nv_drm_semsurf_fence_wait_ioctl(struct drm_device *dev,
     unsigned long flags;
     int ret = -EINVAL;
 
+    if (nv_dev->pDevice == NULL) {
+        return -EOPNOTSUPP;
+    }
+
     if (p->pre_wait_value >= p->post_wait_value) {
         NV_DRM_DEV_LOG_ERR(
             nv_dev,
@@ -1743,6 +1766,11 @@ int nv_drm_semsurf_fence_attach_ioctl(struct drm_device *dev,
     nv_dma_fence_t *fence;
     int ret = -EINVAL;
 
+    if (nv_dev->pDevice == NULL) {
+        ret = -EOPNOTSUPP;
+        goto done;
+    }
+
     nv_gem = nv_drm_gem_object_lookup(nv_dev->dev, filep, p->handle);
 
     if (!nv_gem) {
