@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: Copyright (c) 2023 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
+ * SPDX-FileCopyrightText: Copyright (c) 2023-2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  * SPDX-License-Identifier: MIT
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -221,6 +221,8 @@ sec2utilsConstruct_IMPL
     pChannel->type = SWL_SCRUBBER_CHANNEL;
     pChannel->engineType = RM_ENGINE_TYPE_SEC2;
 
+    pChannel->bSecure = NV_TRUE;
+
     // Detect if we can enable fast scrub on this channel
     NV_ASSERT_OK_OR_GOTO(status, _sec2GetClass(pGpu, &pSec2Utils->sec2Class), free_client);
     pChannel->sec2Class = pSec2Utils->sec2Class;
@@ -240,6 +242,8 @@ sec2utilsConstruct_IMPL
 
     pChannel->engineType = NV2080_ENGINE_TYPE_SEC2;
 
+    NV_ASSERT_OK_OR_GOTO(status, channelAllocSubdevice(pGpu, pChannel), free_client);
+
     pMemoryManager->bScrubChannelSetupInProgress = NV_TRUE;
     NV_ASSERT_OK_OR_GOTO(status, memmgrMemUtilsChannelInitialize_HAL(pGpu, pMemoryManager, pChannel), free_channel);
     pMemoryManager->bScrubChannelSetupInProgress = NV_FALSE;
@@ -263,7 +267,7 @@ sec2utilsConstruct_IMPL
 
     NV_ASSERT_OK_OR_GOTO(status, _sec2InitBuffers(pSec2Utils), free_channel);
 
-    NV_ASSERT_OK_OR_GOTO(status, ccslContextInitViaChannel(&pSec2Utils->pCcslCtx, pSec2Utils->hClient, pChannel->channelId), free_channel);
+    NV_ASSERT_OK_OR_GOTO(status, ccslContextInitViaChannel(&pSec2Utils->pCcslCtx, pSec2Utils->hClient, pSec2Utils->hSubdevice, pChannel->channelId), free_channel);
 
     return status;
 
@@ -310,7 +314,7 @@ sec2utilsDestruct_IMPL
     {
         if (kbusIsBarAccessBlocked(GPU_GET_KERNEL_BUS(pGpu)))
         {
-            // 
+            //
             // When PCIE is blocked, mappings should be created, used and torn
             // down when they are used
             //
@@ -375,7 +379,7 @@ sec2utilsServiceInterrupts_IMPL(Sec2Utils *pSec2Utils)
     //
     // FIXME: Bug 2463959: objmemscrub is called with the rmDeviceGpuLock in the
     // heapFree_IMPL->_stdmemPmaFree->pmaFreePages->scrubSubmitPages path.
-    // This can result in RM waiting for scrubbing to complete and yielding while holding the 
+    // This can result in RM waiting for scrubbing to complete and yielding while holding the
     // rmDeviceGpuLock. This can lead to deadlock.
     // Instead, if the lock is held, service any interrupts on SEC2 to help the engine make progress.
     // Bug 2527660 is filed to remove this change.
@@ -453,12 +457,12 @@ _sec2utilsSubmitPushBuffer
     MemoryManager *pMemoryManager = GPU_GET_MEMORY_MANAGER(pChannel->pGpu);
     NvBool bReleaseMapping = NV_FALSE;
 
-    // 
+    //
     // Use BAR1 if CPU access is allowed, otherwise allocate and init shadow
     // buffer for DMA access
     //
-    NvU32 transferFlags = (TRANSFER_FLAGS_USE_BAR1     | 
-                           TRANSFER_FLAGS_SHADOW_ALLOC | 
+    NvU32 transferFlags = (TRANSFER_FLAGS_USE_BAR1     |
+                           TRANSFER_FLAGS_SHADOW_ALLOC |
                            TRANSFER_FLAGS_SHADOW_INIT_MEM);
     NV_PRINTF(LEVEL_INFO, "Actual size of copying to be pushed: %x\n", pChannelPbInfo->size);
 
@@ -470,7 +474,7 @@ _sec2utilsSubmitPushBuffer
     }
 
     if (pChannel->pbCpuVA == NULL)
-    {    
+    {
         pChannel->pbCpuVA = memmgrMemDescBeginTransfer(pMemoryManager, pChannel->pChannelBufferMemdesc,
                                                        transferFlags);
         bReleaseMapping = NV_TRUE;
@@ -495,7 +499,7 @@ _sec2utilsSubmitPushBuffer
         return NV_ERR_NO_FREE_FIFOS;
     }
 
-    // 
+    //
     // Pushbuffer can be written in a batch, but GPFIFO and doorbell require
     // careful ordering so we do each write one-by-one
     //
