@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: Copyright (c) 2021-2023 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
+ * SPDX-FileCopyrightText: Copyright (c) 2021-2025 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  * SPDX-License-Identifier: MIT
  *
  * Permission is hereby granted, free of charge, to any person obtaining a
@@ -406,6 +406,11 @@ destroyKernelHostVgpuDeviceShare(OBJGPU *pGpu, KernelHostVgpuDeviceShr* pShare)
         RM_API *pRmApi = GPU_GET_PHYSICAL_RMAPI(pGpu);
         NV2080_CTRL_VGPU_MGR_INTERNAL_SHUTDOWN_GSP_VGPU_PLUGIN_TASK_PARAMS shutdownParams = { 0 };
         NV2080_CTRL_VGPU_MGR_INTERNAL_VGPU_PLUGIN_CLEANUP_PARAMS cleanupResourcesParams = {0};
+        // Extend timeout to 30s for these calls to account for long-running mass client free (bug 4928590)
+        // Otherwise this can hit XID 119 and orphan all remaining clients on GSP side
+        NvU32 defaultus = pGpu->timeoutData.defaultus;
+
+        pGpu->timeoutData.defaultus = 30*1000*1000;
 
         shutdownParams.gfid = pKernelHostVgpuDevice->gfid;
 
@@ -419,6 +424,7 @@ destroyKernelHostVgpuDeviceShare(OBJGPU *pGpu, KernelHostVgpuDeviceShr* pShare)
         status = pRmApi->Control(pRmApi, pGpu->hInternalClient, pGpu->hInternalSubdevice,
                                  NV2080_CTRL_CMD_VGPU_MGR_INTERNAL_VGPU_PLUGIN_CLEANUP,
                                  &cleanupResourcesParams, sizeof(cleanupResourcesParams));
+        pGpu->timeoutData.defaultus = defaultus;
         if (status != NV_OK)
             NV_PRINTF(LEVEL_ERROR, "Failed to call cleanup plugin resources\n");
 
